/**
 * Copyright (c) 2014-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.registry.client.api;

import java.net.InetAddress;
import java.util.Map;

import org.ow2.petals.registry.client.api.exception.ConnectionErrorException;
import org.ow2.petals.registry.client.api.exception.UnexistingTopologyException;
import org.ow2.petals.topology.generated.Topology;

/**
 * Interface of a Petals Registry Client.
 * 
 * @author Christophe DENEUX - Linagora
 */
public interface PetalsRegistryClient {

    /**
     * @return The IP address of the cluster member on which the client is connected.
     */
    public InetAddress getHost();

    /**
     * @return The TCP port of the cluster member on which the client is connected.
     */
    public int getPort();

    /**
     * @return The credential group name with which the client is connected.
     */
    public String getGroup();

    /**
     * Release the connection to the JMX server
     * 
     * @throws ConnectionErrorException
     */
    public void disconnect() throws ConnectionErrorException;

    /**
     * @return All topology definitions registered
     */
    public Map<String, Topology> getTopologies();

    /**
     * @param topologyId
     *            The topology identifier
     * @return The definition of the topology
     */
    public Topology getTopology(final String topologyId);

    /**
     * Clean all information associated to the given topology from the Petals Registry Overlay cluster.
     * 
     * @param topology
     *            Name of the topology to clean
     * @throws UnexistingTopologyException
     *             The given topology does not exist in the Petals Registry Overlay cluster
     */
    public void clean(final String topology) throws UnexistingTopologyException;
}
